@@ -77,12 +77,13 @@ Please specify something like '?charset=utf8' explicitly.""")
 
 
     @staticmethod
-    def foreign_key(ref_model, ref_name = None, backref_name = None):
+    def foreign_key(ref_model, ref_name = None, backref_name = None, one_to_one = False):
         """"Class decorator, add a foreign key to a SQLAlchemy model.
         Parameters:
         ref_model is the destination model, in a one-to-many relationship, it is the "one" side.
         ref_name is the user-friendly name of destination model(if omitted, destintion table name will be used instead).
         backref_name is the name used to back ref the "many" side.
+        one_to_one: is this foreign_key for a one-to-one relationship?
         """
         if isinstance(ref_model, str):
             ref_model_name = ref_model
@@ -97,14 +98,23 @@ Please specify something like '?charset=utf8' explicitly.""")
             setattr(cls, foreign_key, Column(Integer, ForeignKey('{0}.id'.format(ref_table_name))))
             # Assign to backref_name will change it to a local variable which we don't want to, so we have to create a new variable.
             # reference: http://docs.python.org/tutorial/classes.html#python-scopes-and-namespaces
-            my_backref_name = backref_name or '{0}s'.format(table_name)
+            my_backref_name = backref_name or (table_name if one_to_one else '{0}s'.format(table_name))
+            backref_options = dict(uselist = False) if one_to_one else dict(lazy = 'dynamic')
             setattr(cls, ref_name, relationship(ref_model_name, 
                 primaryjoin = '{0}.{1} == {2}.id'.format(model_name, foreign_key, ref_model_name), 
-                backref = backref(my_backref_name, lazy = 'dynamic'), remote_side = '{0}.id'.format(ref_model_name)))
+                backref = backref(my_backref_name, **backref_options), remote_side = '{0}.id'.format(ref_model_name)))
             return cls
         return ref_table
 
 
+    @staticmethod
+    def one_to_one(ref_model, ref_name = None, backref_name = None):
+        """Add a one-to-one relationship between two models.
+        This method is a shortcut to the method Database.foreign_key(ref_model, ref_name, backref_name, True)
+        """
+        return Database.foreign_key(ref_model, ref_name, backref_name, True)
+
+
     @staticmethod
     def many_to_many(ref_model, ref_name = None, backref_name = None, middle_table_name = None):
         """Class Decorator, add a many-to-many relationship between two SQLAlchemy models.
@@ -156,7 +166,8 @@ Please specify something like '?charset=utf8' explicitly.""")
         def __new__(cls, name, bases, attrs):
             # add Database.BaseModel as parent class
             bases = list(bases)
-            if object in bases:
+            # no need to inherit object because it's going to inherit other classes which already inherited object
+            if object in bases: 
                 bases.remove(object)
             bases.append(Database.BaseModel)
             seen = set()
