@@ -2,26 +2,30 @@ examples_list = [
     'hello_world',
     'foreign_key',
     'foreign_key_options',
+    'foreign_key_to_self',
     'many_to_many',
     'many_to_many_options',
+    'many_to_many_to_self',
     'one_to_one',
     'multiple_foreign_keys',
     'raw_sql',
     'multiple_databases',
     'table_inheritance',
-    'write_less_do_more',
+    'meta_builder',
 ]
 
 examples_dict = {
     'hello_world': 'Hello World',
     'foreign_key': 'Foreign key',
     'foreign_key_options': 'Foreign key options',
+    'foreign_key_to_self': 'Foreign key to oneself',
     'many_to_many': 'Many-to-many relationship',
     'many_to_many_options': 'Many-to-many relationship options',
+    'many_to_many_to_self': 'Many-to-many relationship with oneself',
     'one_to_one': 'One-to-one relationship',
     'multiple_foreign_keys': 'Multiple foreign keys',
     'raw_sql': 'Performing raw sql query',
     'multiple_databases': 'Multiple databases',
     'table_inheritance': 'Table inheritance',
-    'write_less_do_more': 'Write less, do more',    
+    'meta_builder': 'MetaBuilder to avoid dupliate code',
 }
